diff --git a/setup.py b/setup.py
index 69419aeb089449d7ac516f2d361032cf4e2b0321..ffcf92bb1731a334a964db1c2386c6937c018bae 100644
--- a/setup.py
+++ b/setup.py
@@ -124,7 +124,7 @@ setup(
             'imglob        = fsl.scripts.imglob:main',
             'atlasq        = fsl.scripts.atlasq:main',
             'atlasquery    = fsl.scripts.atlasq:atlasquery_emulation',
-            'extract_noise = fsl.scripts.extract_noise:main',
+            'fsl_ents = fsl.scripts.extract_noise:main',
         ]
     }
 )
diff --git a/tests/test_extract_noise.py b/tests/test_extract_noise.py
index 6c1e4b8ed7b588b6e68351c3504710293deffbdc..7bb4b99176316fb5e7efe04710db77a3de2ec700 100644
--- a/tests/test_extract_noise.py
+++ b/tests/test_extract_noise.py
@@ -95,7 +95,7 @@ def test_extract_noise():
         melmix = np.random.randint(1, 100, (100, 20))
         np.savetxt('melodic_mix', melmix)
 
-        sys.argv = ['extract_noise', td] + '-o out.txt 1 2 3'.split()
+        sys.argv = ['fsl_ents', td] + '-o out.txt 1 2 3'.split()
         extn.main()
         assert np.all(np.loadtxt('out.txt') == melmix[:, :3])
diff --git a/fsl/scripts/extract_noise.py b/fsl/scripts/extract_noise.py
index 087aceb813d8d8459786d03dca15f254b4758844..bb4f5025e33b013df891599a99d6b6719a6b23d3 100644
--- a/fsl/scripts/extract_noise.py
+++ b/fsl/scripts/extract_noise.py
@@ -5,7 +5,7 @@
 #
 # Author: Paul McCarthy <pauldmccarthy@gmail.com>
 #
 """This module defines the ``extract_noise`` script, for extracting component
 time series from a MELODIC ``.ica`` directory.
 """
 
@@ -28,7 +28,7 @@ with warnings.catch_warnings():
 
 
 DTYPE = np.float64
-name  = "extract_noise"
+name  = "fsl_ents"
 desc  = 'Extract component time series from a MELODIC .ica directory'
 usage = """
 {name}: {desc}
@@ -204,7 +204,7 @@ def loadConfoundFiles(conffiles, npts):
 
 
 def main(argv=None):
     """Entry point for the ``extract_noise`` script.
 
     Identifies component time series to extract, extracts them, loads extra
     confound files, and saves them out to a file.
@@ -5,7 +5,7 @@
 # Author: Paul McCarthy <pauldmccarthy@gmail.com>
 #
-"""This module defines the ``extract_noise`` script, for extracting component
+"""This module defines the ``fsl_ents`` script, for extracting component
 time series from a MELODIC ``.ica`` directory.
 """
@@ -204,7 +204,7 @@ def loadConfoundFiles(conffiles, npts):
 
 def main(argv=None):
-    """Entry point for the ``extract_noise`` script.
+    """Entry point for the ``fsl_ents`` script.
 
     Identifies component time series to extract, extracts them, loads extra